v0.3.0 (2021-02-10)
-------------------
- Support & test against Click 6
- Support custom log levels

v0.2.0 (2021-02-02)
-------------------
- Renamed the class from `LogLevelType` to `LogLevel`.  The old name is still
  available (for now) as an alias.

v0.1.0 (2021-02-01)
-------------------
Initial release
